//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

package com.cloud.agent.api;

import com.cloud.utils.Pair;
import org.junit.Assert;
import org.junit.Test;
import org.mockito.Mockito;

import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class GetHypervisorGuestOsNamesAnswerTest {

    @Test
    public void testGuestOsMappingAnswerSuccess() {
        List<Pair<String, String>> hypervisorGuestOsNames = new ArrayList<>();
        hypervisorGuestOsNames.add(new Pair<>("centos", "centos"));
        GetHypervisorGuestOsNamesCommand cmd = new GetHypervisorGuestOsNamesCommand();
        GetHypervisorGuestOsNamesAnswer answer = new GetHypervisorGuestOsNamesAnswer(cmd, hypervisorGuestOsNames);
        List<Pair<String, String>> resultOsNames = answer.getHypervisorGuestOsNames();

        Assert.assertEquals("centos", resultOsNames.get(0).first());
        assertTrue(answer.getResult());
    }

    @Test
    public void testGuestOsMappingAnswerFailure1() {
        Throwable th = Mockito.mock(Throwable.class);
        Mockito.when(th.getMessage()).thenReturn("failure");
        GetHypervisorGuestOsNamesCommand cmd = new GetHypervisorGuestOsNamesCommand();
        GetHypervisorGuestOsNamesAnswer answer = new GetHypervisorGuestOsNamesAnswer(cmd, th);

        Assert.assertEquals("failure", answer.getDetails());
        assertFalse(answer.getResult());
    }

    @Test
    public void testGuestOsMappingAnswerFailure2() {
        GetHypervisorGuestOsNamesCommand cmd = new GetHypervisorGuestOsNamesCommand();
        GetHypervisorGuestOsNamesAnswer answer = new GetHypervisorGuestOsNamesAnswer(cmd, "failure");

        Assert.assertEquals("failure", answer.getDetails());
        assertFalse(answer.getResult());
    }
}
